@@ -164,6 +164,10 @@ class Service(object):
             files = ['inventory/group_vars/gitlab/gitlab.yml']
         elif service == 'website':
             urls = [f'https://www.{domain}']
+        elif service == 'pages':
+            urls = [f'https://www.{domain}']
+        elif service == 'hosteadashboard':
+            urls = [f'https://hosteadashboard.{domain}']
         elif service == 'wekan':
             urls = [f'https://wekan.{domain}']
             comment = 'user=admin'
