@@ -1,6 +1,4 @@
-from icinga2api.exceptions import Icinga2ApiException
 from tests.icinga_helper import IcingaHelper
-import pytest
 
 testinfra_hosts = ['ansible://icinga-host']
 
@@ -8,11 +6,9 @@ testinfra_hosts = ['ansible://icinga-host']
 class TestChecks(IcingaHelper):
 
     def test_icinga_host(self):
-        objects = self.get_client().objects
-        r = objects.get('Host', 'bind-host')
-        assert r['attrs']['name'] == 'bind-host'
-        with pytest.raises(Icinga2ApiException):
-            objects.get('Host', 'deleted-host')
+        hosts = self.get_hosts()
+        assert 'bind-host' in hosts
+        assert 'deleted-host' not in hosts
 
     def test_icinga_service(self, host):
         #  r = self.get_client().objects.list('Service', joins=['host.name'])
