@@ -80,7 +80,7 @@ class Wazuh(object):
         @retry.retry(AssertionError, tries=8)
         def wait_for_syscheck():
             current_last = self.get_syscheck_end(agent)
-            assert current_last is not None, f'syscheck in progress'
+            assert current_last is not None, 'syscheck in progress'
             assert current_last > last, f'{current_last} > {last}'
         wait_for_syscheck()
 
