@@ -8,8 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        r = self.get_client().objects.get('Host', 'wordpress-host')
-        assert r['attrs']['name'] == 'wordpress-host'
+        assert 'wordpress-host' in self.get_hosts(host='wordpress-host')
 
     def test_service(self, host):
         assert self.is_service_ok('wordpress-host!WordPress')
