@@ -10,7 +10,18 @@ from enough.common.dotenough import Hosts, DotEnoughLibvirt
 @pytest.mark.libvirt_integration
 def test_libvirt_install(dotenough_libvirt_fixture):
     config_dir = dotenough_libvirt_fixture.config_dir
-    open(f'{config_dir}/hypervisor.conf', 'w').write('SOME')
+    open(f'{config_dir}/hypervisor.conf', 'w').write("""
+port 1194
+proto udp
+dev tun
+keepalive 10 120
+remote 1.2.3.4
+cipher AES-256-CBC
+user nobody
+group nogroup
+persist-key
+persist-tun
+    """)
     sh.tar('zcvf', 'hypervisor.tar.gz', 'hypervisor.conf', _cwd=config_dir)
     clouds = 'CLOUDS: cool'
     all_dir = f'{config_dir}/inventory/group_vars/all'
